@@ -469,7 +469,7 @@ class LvmBinary(ExternalBinary):
 class LvmCLI():
     lvs = LvmBinary().lvs
     vgs = LvmBinary().vgs
-    lvcreate = LvmBinary().lvcreate
+    lvcreate = ExternalBinary().lvcreate
     lvchange = LvmBinary().lvchange
     lvremove = LvmBinary().lvremove
     lvextend = LvmBinary().lvextend
@@ -1001,6 +1001,8 @@ class Rsync():
     def sync(self, sourcetree, dst):
         assert os.path.isdir(sourcetree), "%s is not a directory" % sourcetree
 
+        self._run(["restorecon", "-Rv", sourcetree])
+
         cmd = ["rsync"]
         cmd += ["-pogAXlHrx"]
         cmd += ["-SWc", "--no-i-r"]
